# -*- coding: utf-8 -*-

import os
import warnings


def check_file_existence(path_):
    if not os.path.isfile(path_):
        raise FileNotFoundError(path_)


def check_dir_existence(path_):
    if not os.path.isdir(path_):
        raise FileNotFoundError(path_)


def mkdir(path_):
    if not os.path.exists(path_):
        os.makedirs(path_)
        return True
    else:
        warnings.warn(path_, ' already exists!')
        return False


if __name__ == "__main__":
    pass



# -*- coding: utf-8 -*-

import sys


class _const:
    class ConstError(TypeError):
        pass

    def __setattr__(self, key, value):
        if key in self.__dict__:
            raise self.ConstError("constant reassignment error!")
        self.__dict__[key] = value


sys.modules[__name__] = _const()






# -*- coding: utf-8 -*-


def is_number(s):
    try:
        float(s)
        return True
    except ValueError:
        pass
    try:
        import unicodedata
        unicodedata.numeric(s)
        return True
    except (TypeError, ValueError):
        pass
    return False


if __name__ == "__main__":
    print(is_number(4))
    print(is_number(4.5))
    print(is_number(1e-4))
    print(is_number('st'))
    print(is_number(' '))
